import os,yaml
from ..utils.logger import show_help
from ..utils.context import Context
import subprocess

def activate():
  root_path = Context.root_path
  output = subprocess.check_output("pip -V", shell=True).decode('utf-8')
  if not output.__contains__('python_modules'):
    print("Error: You must activate python_modules first")
    print("Hint: ")
    print(" source ./python_modules/bin/activate")
    print("")

def help():
  show_help(
    command='activate',
    description='Show if your python_modules is activated or not',
    usage=[
      {
        'command': 'activate',
        'description': 'Checks for your virtual environment'
      },
    ]
  )